@@ -225,8 +225,8 @@ int main(int argc, char **argv){
 	get_image_bitmap(&dfr, opt, image_hdr, bitmap);
 
 	/// check the dest partition size.
-	if((opt.check) && (check_size(&dfw, image_hdr.device_size) != 0))
-            log_mesg(0, 0, 1, debug, "Can't get device size, use option -C to disable size checkinh.\n");
+	if((opt.check) && (check_size(&dfw, image_hdr.device_size) != 1))
+            log_mesg(0, 1, 1, debug, "Can't get device size, use option -C to disable size checking.\n");
 
 	log_mesg(2, 0, 0, debug, "check main bitmap pointer %i\n", bitmap);
     } else if (opt.dd){
@@ -255,8 +255,8 @@ int main(int argc, char **argv){
 	readbitmap(source, image_hdr, bitmap);
 	
 	/// check the dest partition size.
-	if((opt.check) && (check_size(&dfw, image_hdr.device_size) != 0))
-            log_mesg(0, 0, 1, debug, "Can't get device size, use option -C to disable size checkinh.\n");
+	if((opt.check) && (check_size(&dfw, image_hdr.device_size) != 1))
+            log_mesg(0, 1, 1, debug, "Can't get device size, use option -C to disable size checking.\n");
 
 	log_mesg(2, 0, 0, debug, "check main bitmap pointer %i\n", bitmap);
     }
